.. index::
   single: Function reference; Structure containers
   single: Class reference; Structure containers

Structure containers
====================

.. autoclass:: icet.StructureContainer
   :members:
   :undoc-members:
   :inherited-members:
